<?php
class UsersAdmin
{
  private $dbo = null;
  function __construct($dbo)
  {
    $this->dbo = $dbo;
  }
  
  function getQuerySingleResult($query)
  {
    //Brak obiektu $dbo
    if(!$this->dbo) return false;
    
    //Wykonanie zapytania.
    if(!$result = $this->dbo->query($query)){
      //echo 'Wystąpił błąd (getQuerySingleResult): nieprawidłowe zapytanie...';
      return false;
    }
    if($row = $result->fetch_row()){
      //Zwrócenie wyniku.
      return $row[0];
    }
    else{
      //Brak wyników zapytania.
      return false;
    }
  }
  
  function getPagination($page, $pages, $link, $msg)
  {
    $str = '';
    for($i = 0; $i < $pages; $i++){
      if($i != $page){
        $str .= "<a href=\"$link&amp;page=$i\">".($i+1)."</a>";
      }
      else{
        $str .= '<span class="activePaginationPage">' . ($i+1)
              . '</span>';
      }
      $str .= '<span class="space"> </span>';
    }
    $str = $msg . $str;
    return $str;
  }
  
  function showList($limit)
  {
    if(!$this->dbo){
      echo 'Lista użytkowników nie jest dostępna.';
      return;
    }
    
    //Odczytanie parametru page
    if(isset($_GET['page'])){
      $page = intval($_GET['page']);
    }
    else{
      $page = 0;
    }
    
    //Określenie całkowitej liczby wierszy w tabeli Users
    $query = "SELECT COUNT(*) FROM Users";
    $rowsCount = (int) $this->getQuerySingleResult($query);
    
    //Obliczenie całkowitej liczby stron z wynikami
    $pages = ceil($rowsCount / $limit);
    
    if($page < 0 || $page >= $pages) $page = 0;
    
    $offset = $page * $limit;
    
    //Zapytanie pobierające wyniki dla bieżącej strony
    $query = "SELECT Id, Nazwa, Imie, Nazwisko, Email "
           . "FROM Users LIMIT $offset, $limit";

    if(!$users = $this->dbo->query($query)){
      return;
    }
    include 'templates/usersList.php';
  }
  
  function showEditForm($action)
  {
    if(!$this->dbo) return SERVER_ERROR;
    
    //Edycja istniejącego konta
    if($action == 'edit'){
      //Sprawdzenie czy istnieje parametr id
      if(!isset($_GET['id'])){
        echo 'Brak parametru id.';
        return FORM_DATA_MISSING;
      }
      
      //Sprawdzenie poprawności parametru id
      if(($id = (int)($_GET['id'])) < 1){
        echo 'Nieprawidłowy parametr id.';
        return INVALID_USER_ID;
      }
      
      //Zapytanie pobierające dane
      $query = "SELECT * FROM Users WHERE id=$id";
      
      if(!$result = $this->dbo->query($query)){
        echo 'Błąd serwera. Niewłaściwe zapytanie MySQL.';
        return SERVER_ERROR;
      }
      if(!$row = $result->fetch_row()){
        echo 'Nieprawidłowy parametr id.';
        return INVALID_USER_ID;
      }
      
      //Ustawienie wartości zmiennych używanych w formularzu
      $id = $row[0];
      $nazwa = $row[1];
      $imie = $row[3];
      $nazwisko = $row[4];
      $email = $row[5];
      
      $wtd = 'modifyUser';
      $readonly = 'readonly';
    }
    //Dodawanie nowego konta
    else{
      $id = '';
      $nazwa = '';
      $imie = '';
      $nazwisko = '';
      $email = '';
      $wtd = 'addUser';
      $readonly = '';
    }
    include 'templates/editUserForm.php';
  }
  
  function editUser($action, &$id)
  {
    if(!$this->dbo) return SERVER_ERROR;
    
    //Sprawdzenie czy zostały przekazane dane.
    if(!isset($_POST['id']) || !isset($_POST['nazwa']) || 
       !isset($_POST['imie']) || !isset($_POST['nazwisko']) || 
       !isset($_POST['email']) || !isset($_POST['haslo'])){
      return FORM_DATA_MISSING;
    }
    
    //Zapis danych w zmiennych pomocniczych.
    $id = (int)$_POST['id'];
    $nazwa = $_POST['nazwa'];
    $haslo = $_POST['haslo'];
    $imie = $_POST['imie'];
    $nazwisko = $_POST['nazwisko'];
    $email = $_POST['email'];
    
    //Sprawdzenie poprawności danych.
    if(($action == 'edit' && $id < 1) ||
       ($action == 'add' && $id < 0)) return INVALID_USER_ID;
    
    if(!preg_match("/^[a-zA-Z0-9_.]{3,20}$/", $nazwa)){
      return INVALID_USER_NAME;
    };
    
    /*
      Tutaj dalsze instrukcje weryfikujące dane.
    */
    
    //Zabezpieczenie znaków specjalnych w parametrach.
    $nazwa = $this->dbo->real_escape_string($nazwa);
    $imie = $this->dbo->real_escape_string($imie);
    $nazwisko = $this->dbo->real_escape_string($nazwisko);
    $email = $this->dbo->real_escape_string($email);
    
    if($action == 'edit'){
      //Kodowanie hasła.
      if($haslo != ''){
        $pass = "Haslo='".crypt($haslo)."', ";
      }
      else{
        $pass = '';
      }
      $query = "UPDATE Users SET Nazwa='$nazwa', Imie='$imie', $pass"
             . "Nazwisko='$nazwisko', Email='$email' WHERE id=$id ";
    }
    else{
      //Sprawdzenie czy istnieje użytkownik o podanej nazwie.
      $query = "SELECT Id FROM Users WHERE Nazwa='$nazwa'";
      if($this->getQuerySingleResult($query) !== false){
        return USER_NAME_ALREADY_EXISTS;
      }
      //Sprawdzenie czy istnieje użytkownik o podanym id.
      if($id > 0){
        $query = "SELECT Id FROM Users WHERE id=$id";
        if($this->getQuerySingleResult($query) !== false){
          return USER_ID_ALREADY_EXISTS;
        }
      }
      
      //Kodowanie hasła.
      $haslo = crypt($haslo);
      
      $query = "INSERT INTO Users VALUES($id, '$nazwa', '$haslo', "
             . "'$imie', '$nazwisko', '$email')";
    }
    
    if($this->dbo->query($query)){
      if($action != 'edit') {
        $id = $this->dbo->insert_id;
      }
      return ACTION_OK;
    }
    else{
      return ACTION_FAILED;
    }
  }
  
  function showSearchForm()
  {
    include 'templates/searchUserForm.php';
  }
  
  function searchUser()
  {
    if(!$this->dbo) return SERVER_ERROR;
    
    //Sprawdzenie czy zostały przekazane dane
    if(!isset($_GET['id']) || !isset($_GET['nazwa'])){
      return FORM_DATA_MISSING;
    }
    
    $id = $_GET['id'];
    $nazwa = $_GET['nazwa'];
    
    if($id == '' && $nazwa == ''){
      return FORM_DATA_MISSING;
    }
    
    //Ustalenie warunku dla identyfikatora
    if($id != ''){
      if(($id = (int)$id) < 1){
        return INVALID_USER_ID;
      }
      $cond1 = " AND id=$id ";
    }
    else{
      $cond1 = '';
    }
    
    //Ustalenie warunku dla nazwy
    if($nazwa != ''){
      if(!preg_match("/^[a-zA-Z0-9_.]{3,20}$/", $nazwa)){
        return INVALID_USER_NAME;
      }
      $nazwa = $this->dbo->real_escape_string($nazwa);
      $cond2 = " AND nazwa='$nazwa' ";
    }
    else{
      $cond2 = '';
    }
    
    //Zapytanie pobierające dane
    $query = "SELECT * FROM Users WHERE 1=1 $cond1 $cond2";
    if(!$result = $this->dbo->query($query)){
      return SERVER_ERROR;
    }
    if(!$row = $result->fetch_row()){
      return USER_NOT_FOUND;
    }
    
    //Ustalenie stanu zmiennych dla formularza edycji danych
    $id = $row[0];
    $nazwa = $row[1];
    $imie = $row[3];
    $nazwisko = $row[4];
    $email = $row[5];
    
    $readonly = 'readonly';
    $wtd = 'modifyUser';
    
    //Dołączenie formularza i powrót
    include 'templates/editUserForm.php';
    return ACTION_OK;
  }
  
  function deleteUser()
  {
    if(!$this->dbo) return SERVER_ERROR;
    
    //Sprawdzenie poprawności parametru id
    if(!isset($_GET['id']) || $_GET['id'] < 1){
      return INVALID_USER_ID;
    }
    
    //Formowanie zapytania SQL
    $id = (int) $_GET['id'];
    $query = "DELETE FROM Users WHERE id = $id";
    
    if(!$this->dbo->query($query)){
      return SERVER_ERROR;
    }
    
    //Rezultat działania metody
    if($this->dbo->affected_rows == 0){
      return USER_NOT_FOUND;
    }
    else{
      return ACTION_OK;
    }
  }
}
?>